Enum Rovsm
#[repr(u8)]pub enum Rovsm {
Continued = 0,
Resumed = 1,
}Variants
Continued = 0
Continued mode: When injected conversions are triggered, the oversampling is temporary stopped and continued after the injection sequence (oversampling buffer is maintained during injected sequence).
Resumed = 1
Resumed mode: When injected conversions are triggered, the current oversampling is aborted and resumed from start after the injection sequence (oversampling buffer is zeroed by injected sequence start).
Implementations